# 🚀 Easy Gateway


<table>
	<tr align="center">
		<td>PyPI Counter</td>
		<td><a href="https://pepy.tech/projects/easy-gateway"><img src="https://static.pepy.tech/badge/easy-gateway" alt="PyPI Downloads"></a></td>
	</tr>
	<tr align="center">
		<td>Github Stars</td>
		<td><a href="https://github.com/MarkLevkovich/easy_gateway"><img src="https://img.shields.io/github/stars/MarkLevkovich/easy_gateway.svg?style=social&label=Stars"></a></td>
	</tr>
</table>


A simple to use and lightweight API Gateway for microservice architecture.

## ✨ Features

- ✅ Easy setup via YAML
- ✅ CLI interface
- ✅ Middleware system
- ✅ Routing with prefixes
- ✅ Rate limiting
- ✅ Logging
- ✅ Cache (Redis / InMemory)

## 📦 Install



```bash
pip install easy-gateway
```
DOCS:
[Visit](https://marklevkovich.github.io/easy-gateway-docs/)
